@@ -17,7 +17,7 @@ impl EventStream {
         let mut init = [0_u8; 14];
         let _len = self.inner.read_exact(&mut init).await?;
 
-        assert!(!(&init[0..6] != MAGIC.as_bytes()), "Magic str not received");
+        assert!(&init[0..6] == MAGIC.as_bytes(), "Magic str not received");
         let payload_len = u32::from_ne_bytes([init[6], init[7], init[8], init[9]]) as usize;
         let msg_type = u32::from_ne_bytes([init[10], init[11], init[12], init[13]]);
 
